DROP TABLE Asset;

CREATE TABLE Asset (
   Asset_No integer NOT NULL,
   Asset_Name varchar(120) NOT NULL,
   Purchase_Date varchar(10) NOT NULL,
   Org_Amt numeric(10,2) NOT NULL,
   Detail_Description varchar(250) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Asset_Asset_No ON Asset (Asset_No,Asset_Name);

CREATE INDEX Asset_Purchase_Date ON Asset (Purchase_Date);

DROP TABLE Asset_Item;

CREATE TABLE Asset_Item (
   Asset_No integer NOT NULL,
   Asset_Name varchar(120) NOT NULL,
   Asset_Item varchar(100) NOT NULL,
   Purchase_Date varchar(10) NOT NULL,
   Purchase_Amt numeric(10,2) NOT NULL,
   Detail_Description varchar(250) NULL
);

CREATE UNIQUE CLUSTERED INDEX Asset_Item_Asset_No ON Asset_Item (Asset_No,Asset_Name,Asset_Item);

CREATE INDEX Asset_Item_Purchase_Date ON Asset_Item (Purchase_Date);

DROP TABLE Assigned_To;

CREATE TABLE Assigned_To (
   Schedule_No integer NOT NULL,
   Name varchar(60) NOT NULL,
   Status varchar(20) NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Assigned_To_Schedule_No ON Assigned_To (Schedule_No,Name);

DROP TABLE batchtable;

CREATE TABLE batchtable (
   run varchar(50) NOT NULL,
   position varchar(50) NULL,
   tstamp varchar(20) NULL,
   dstamp varchar(20) NULL,
   scale1 varchar(50) NULL,
   scale2 varchar(50) NULL,
   scale3 varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX batchtable_run ON batchtable (run);

DROP TABLE BinBatchData;

CREATE TABLE BinBatchData (
   run varchar(50) NOT NULL,
   Bin_No varchar(30) NOT NULL,
   Batch_No varchar(10) NOT NULL,
   Bin_Name varchar(30) NOT NULL,
   Bin_Mass varchar(10) NULL,
   Date_Stamp varchar(30) NULL,
   Time_Stamp varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX BinBatchData_run ON BinBatchData (run,Bin_No,Batch_No,Bin_Name);

DROP TABLE Carrier;

CREATE TABLE Carrier (
   Name varchar(20) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Mobile_No varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN varchar(20) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Carrier_Name ON Carrier (Name);

DROP TABLE Check_List;

CREATE TABLE Check_List (
   Schedule_No integer NOT NULL,
   Section_No varchar(20) NOT NULL,
   Section_Name varchar(60) NOT NULL,
   Item_Id varchar(20) NOT NULL,
   Name varchar(60) NOT NULL,
   Title_Name varchar(100) NOT NULL,
   Description varchar(250) NOT NULL,
   Check_Order integer NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Check_List_Schedule_No ON Check_List (Schedule_No,Title_Name);

CREATE INDEX Check_List_Section_No ON Check_List (Section_No);

CREATE INDEX Check_List_Section_Name ON Check_List (Section_Name);

CREATE INDEX Check_List_Item_Id ON Check_List (Item_Id);

CREATE INDEX Check_List_Name ON Check_List (Name);

DROP TABLE Company;

CREATE TABLE Company (
   Name varchar(30) NOT NULL,
   Report_by varchar(4) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN varchar(15) NULL,
   ACN varchar(15) NULL,
   Web_Site varchar(40) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Company_Name ON Company (Name);

DROP TABLE Constituent;

CREATE TABLE Constituent (
   Constituent varchar(20) NOT NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Constituent_Constituent ON Constituent (Constituent);

DROP TABLE Customer;

CREATE TABLE Customer (
   Cust_no varchar(6) NOT NULL,
   Name varchar(30) NOT NULL,
   Address varchar(50) NOT NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Sales_Tax varchar(10) NULL,
   Pallets_Owing numeric(6,0) NULL,
   Customer_Category varchar(30) NULL,
   Report_by varchar(4) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Cust_no ON Customer (Cust_no);

CREATE INDEX Customer_Name ON Customer (Name);

CREATE INDEX Customer_Pallets_Owing ON Customer (Pallets_Owing);

CREATE INDEX Customer_Customer_Category ON Customer (Customer_Category);

DROP TABLE Cust_Category;

CREATE TABLE Cust_Category (
   Customer_Category varchar(30) NOT NULL,
   Description varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cust_Category_Customer_Category ON Cust_Category (Customer_Category);

DROP TABLE Cust_Location;

CREATE TABLE Cust_Location (
   Cust_no varchar(6) NOT NULL,
   Location_Name varchar(30) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cust_Location_Cust_no ON Cust_Location (Cust_no,Location_Name);

DROP TABLE Cust_Raw_Order;

CREATE TABLE Cust_Raw_Order (
   Order_No varchar(20) NOT NULL,
   Cust_no varchar(6) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Status varchar(15) NULL,
   Comments varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cust_Raw_Order_Order_No ON Cust_Raw_Order (Order_No,Cust_no,Order_Date);

DROP TABLE Cust_Raw_Order_Item;

CREATE TABLE Cust_Raw_Order_Item (
   Order_No varchar(20) NOT NULL,
   Cust_no varchar(6) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Location_Name varchar(30) NOT NULL,
   Qty_Ordered numeric(10,2) NOT NULL,
   Total_Delivered numeric(10,2) NULL,
   Total_Undelivered numeric(10,2) NULL,
   Status varchar(12) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cust_Raw_Order_Item_Order_No ON Cust_Raw_Order_Item (Order_No,Cust_no,Order_Date,Raw_Material_Name);

CREATE INDEX Cust_Raw_Order_Item_Location_Name ON Cust_Raw_Order_Item (Location_Name);

DROP TABLE Delivery_Docket;

CREATE TABLE Delivery_Docket (
   Cust_no varchar(6) NOT NULL,
   Order_No varchar(20) NOT NULL,
   Name varchar(30) NULL,
   Order_Date varchar(10) NOT NULL,
   Seq_Number integer NOT NULL,
   Inv_Seq integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Recipe_No integer NOT NULL,
   Carrier_Name varchar(20) NOT NULL,
   Qty_Delivered numeric(10,2) NOT NULL,
   Qty_Returned numeric(10,2) NULL,
   Delivered_Date varchar(10) NOT NULL,
   No_Bags numeric(10,2) NULL,
   Pallets_In numeric(6,0) NOT NULL,
   Pallets_Out numeric(6,0) NOT NULL,
   Status varchar(10) NULL,
   Invoice_No varchar(15) NULL,
   Credit varchar(4) NULL,
   Shipping_Carrier varchar(30) NULL,
   Vessel_Name varchar(40) NULL,
   Port_of_Discharge varchar(70) NULL,
   E_T_A varchar(10) NULL,
   Container_No varchar(20) NULL,
   Seal_No varchar(20) NULL,
   CL_Cust_No varchar(6) NULL,
   Location_Name varchar(30) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Delivery_Docket_Cust_no ON Delivery_Docket (Cust_no,Order_No,Order_Date,Seq_Number,Inv_Seq,Family_Name,Family_Type,Product_Size,Package_Size,Recipe_No);

CREATE INDEX Delivery_Docket_Delivered_Date ON Delivery_Docket (Delivered_Date);

CREATE INDEX Delivery_Docket_Status ON Delivery_Docket (Status);

CREATE INDEX Delivery_Docket_Invoice_No ON Delivery_Docket (Invoice_No);

CREATE INDEX Delivery_Docket_Location_Name ON Delivery_Docket (Location_Name);

DROP TABLE Docket_No;

CREATE TABLE Docket_No (
   Table_Name varchar(10) NOT NULL,
   Next_Docket_No integer NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Docket_No_Table_Name ON Docket_No (Table_Name);

CREATE INDEX Docket_No_Next_Docket_No ON Docket_No (Next_Docket_No);

DROP TABLE ErrorMessage;

CREATE TABLE ErrorMessage (
   emRef integer NOT NULL,
   emText varchar(255) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX ErrorMessage_emRef ON ErrorMessage (emRef);

DROP TABLE Extruder_Performance;

CREATE TABLE Extruder_Performance (
   Operating_Date varchar(10) NOT NULL,
   Operating_Time varchar(8) NOT NULL,
   Feed_Rate integer NULL,
   Oil_Flow integer NULL,
   Water_Flow_D integer NULL,
   Water_Flow_E integer NULL,
   Steam_Flow_D integer NULL,
   Steam_Flow_E integer NULL,
   Motor_Torque integer NULL,
   Die_Press integer NULL,
   Prod_Temp integer NULL,
   Knife_Speed integer NULL,
   Drier_Temp_1 integer NULL,
   Drier_Temp_2 integer NULL,
   Drier_Temp_3 integer NULL,
   Bed_Speed_1 integer NULL,
   Bed_Speed_2 integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Extruder_Performance_Operating_Date ON Extruder_Performance (Operating_Date,Operating_Time);

DROP TABLE Family_Name;

CREATE TABLE Family_Name (
   Family_Name varchar(60) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Family_Name_Family_Name ON Family_Name (Family_Name);

DROP TABLE Family_Type;

CREATE TABLE Family_Type (
   Family_Type varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Family_Type_Family_Type ON Family_Type (Family_Type);

DROP TABLE Finished_Product_Run_Adjust;

CREATE TABLE Finished_Product_Run_Adjust (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Prod_Run_No varchar(6) NOT NULL,
   Adjust_Date varchar(10) NOT NULL,
   Adjust_Qty numeric(10,2) NOT NULL,
   Adjust_By varchar(40) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Finished_Product_Run_Adjust_Recipe_No ON Finished_Product_Run_Adjust (Recipe_No,Family_Name,Family_Type,Product_Size,Package_Size,Prod_Run_No,Adjust_Date);

CREATE INDEX Finished_Product_Run_Adjust_Adjust_By ON Finished_Product_Run_Adjust (Adjust_By);

DROP TABLE FPS_Formula;

CREATE TABLE FPS_Formula (
   General integer NOT NULL,
   Avg_Ration_Remill numeric(10,4) NULL
);

CREATE UNIQUE CLUSTERED INDEX FPS_Formula_General ON FPS_Formula (General);

DROP TABLE Laboratory;

CREATE TABLE Laboratory (
   Lab_Name varchar(60) NOT NULL,
   Supplier_Code varchar(10) NULL,
   Address varchar(150) NULL,
   Suburb varchar(30) NULL,
   State varchar(3) NULL,
   Postcode integer NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Comments varchar(255) NULL,
   Mobile varchar(15) NULL
);

CREATE UNIQUE CLUSTERED INDEX Laboratory_Lab_Name ON Laboratory (Lab_Name);

DROP TABLE Lab_Result;

CREATE TABLE Lab_Result (
   Record_Id integer NOT NULL,
   Sample_Id varchar(20) NOT NULL,
   Sample_Date varchar(10) NOT NULL,
   Sample_Id_No varchar(20) NULL,
   Lab_Name varchar(60) NOT NULL,
   Date_Sent varchar(10) NULL,
   Date_Received varchar(10) NULL,
   Supplier_Name varchar(60) NOT NULL,
   Supplier_Code varchar(10) NOT NULL,
   GRN_No varchar(15) NULL,
   Raw_Material_Name varchar(30) NULL,
   Constituent varchar(20) NULL,
   R_Result numeric(10,2) NULL,
   Prod_Run_No varchar(6) NULL,
   Recipe_No integer NULL,
   Family_Name varchar(60) NULL,
   Product_Size varchar(6) NULL,
   Family_Type varchar(20) NULL,
   MP_Constituent varchar(20) NULL,
   Pallet_No varchar(15) NULL,
   Result numeric(10,2) NULL,
   In_Tolerence varchar(4) NULL,
   Accepted varchar(4) NULL,
   Reason varchar(60) NULL,
   Person_Responsible varchar(40) NULL,
   Invoice_Date varchar(10) NULL,
   Invoice_No varchar(15) NULL,
   Invoice_Amt numeric(10,2) NULL,
   Storage_Location varchar(30) NULL,
   Location_Name varchar(30) NULL,
   File_Location varchar(200) NULL,
   R_Spec_Date varchar(10) NULL,
   R_Spec_Time varchar(8) NULL,
   Spec_Date varchar(10) NULL,
   Spec_Time varchar(8) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Lab_Result_Record_Id ON Lab_Result (Record_Id,Sample_Id,Sample_Date,Lab_Name);

CREATE INDEX Lab_Result_Date_Sent ON Lab_Result (Date_Sent);

CREATE INDEX Lab_Result_Date_Received ON Lab_Result (Date_Received);

CREATE INDEX Lab_Result_Supplier_Name ON Lab_Result (Supplier_Name);

CREATE INDEX Lab_Result_Raw_Material_Name ON Lab_Result (Raw_Material_Name);

CREATE INDEX Lab_Result_Recipe_No ON Lab_Result (Recipe_No);

CREATE INDEX Lab_Result_Family_Name ON Lab_Result (Family_Name);

CREATE INDEX Lab_Result_Person_Responsible ON Lab_Result (Person_Responsible);

CREATE INDEX Lab_Result_Invoice_Date ON Lab_Result (Invoice_Date);

DROP TABLE Location;

CREATE TABLE Location (
   Name varchar(30) NOT NULL,
   Comment varchar(60) NULL,
   Is_Default varchar(4) NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Location_Name ON Location (Name);

DROP TABLE Maint_Request;

CREATE TABLE Maint_Request (
   Maint_No integer NOT NULL,
   Request_Date varchar(10) NOT NULL,
   Status varchar(15) NOT NULL,
   Request_Name varchar(60) NOT NULL,
   Ack_Date varchar(10) NULL,
   Section_No varchar(20) NULL,
   Section_Name varchar(60) NULL,
   Item_Id varchar(20) NULL,
   Name varchar(60) NULL,
   Ack_Name varchar(60) NULL,
   Ack_Details varchar(255) NULL,
   Request_Details varchar(255) NOT NULL,
   Action_Date varchar(10) NULL,
   Action_Name varchar(60) NULL,
   Action_Taken varchar(255) NULL,
   Request_Priority varchar(10) NOT NULL,
   Ack_Priority varchar(10) NULL,
   Assigned_Name varchar(60) NULL,
   Est_Time varchar(20) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maint_Request_Maint_No ON Maint_Request (Maint_No);

CREATE INDEX Maint_Request_Request_Date ON Maint_Request (Request_Date);

CREATE INDEX Maint_Request_Request_Name ON Maint_Request (Request_Name);

CREATE INDEX Maint_Request_Section_No ON Maint_Request (Section_No);

CREATE INDEX Maint_Request_Section_Name ON Maint_Request (Section_Name);

CREATE INDEX Maint_Request_Item_Id ON Maint_Request (Item_Id);

CREATE INDEX Maint_Request_Name ON Maint_Request (Name);

CREATE INDEX Maint_Request_Ack_Name ON Maint_Request (Ack_Name);

CREATE INDEX Maint_Request_Action_Name ON Maint_Request (Action_Name);

CREATE INDEX Maint_Request_Assigned_Name ON Maint_Request (Assigned_Name);

DROP TABLE Maint_Schedule;

CREATE TABLE Maint_Schedule (
   Schedule_No integer NOT NULL,
   Section_No varchar(20) NOT NULL,
   Section_Name varchar(60) NOT NULL,
   Item_Id varchar(20) NOT NULL,
   Name varchar(60) NOT NULL,
   Schedule_Name varchar(60) NULL,
   Maint_Details varchar(255) NULL,
   Period varchar(20) NULL,
   Monday bit NOT NULL,
   Monday_Pm bit NOT NULL,
   Tuesday bit NOT NULL,
   Tuesday_Pm bit NOT NULL,
   Wednesday bit NOT NULL,
   Wednesday_Pm bit NOT NULL,
   Thursday bit NOT NULL,
   Thursday_Pm bit NOT NULL,
   Friday bit NOT NULL,
   Friday_Pm bit NOT NULL,
   Saturday bit NOT NULL,
   Saturday_Pm bit NOT NULL,
   Sunday bit NOT NULL,
   Sunday_Pm bit NOT NULL,
   Specific_Date1 varchar(10) NULL,
   Specific_Date2 varchar(10) NULL,
   Specific_Time varchar(8) NULL,
   Frequency varchar(20) NULL,
   Priority varchar(10) NOT NULL,
   Est_Time varchar(20) NULL,
   Status varchar(15) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maint_Schedule_Schedule_No ON Maint_Schedule (Schedule_No);

CREATE INDEX Maint_Schedule_Section_No ON Maint_Schedule (Section_No);

CREATE INDEX Maint_Schedule_Section_Name ON Maint_Schedule (Section_Name);

CREATE INDEX Maint_Schedule_Item_Id ON Maint_Schedule (Item_Id);

CREATE INDEX Maint_Schedule_Name ON Maint_Schedule (Name);

CREATE INDEX Maint_Schedule_Schedule_Name ON Maint_Schedule (Schedule_Name);

DROP TABLE Maint_Supplier;

CREATE TABLE Maint_Supplier (
   Supplier_Name varchar(60) NOT NULL,
   Address varchar(150) NULL,
   Suburb varchar(30) NULL,
   State varchar(3) NULL,
   Postcode integer NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Comments varchar(255) NULL,
   Mobile varchar(15) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maint_Supplier_Supplier_Name ON Maint_Supplier (Supplier_Name);

DROP TABLE Maker;

CREATE TABLE Maker (
   Company_Name varchar(60) NOT NULL,
   Address varchar(80) NULL,
   Suburb varchar(30) NULL,
   State varchar(3) NULL,
   Postcode integer NULL,
   Comments varchar(255) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Mobile varchar(15) NULL,
   Email varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maker_Company_Name ON Maker (Company_Name);

DROP TABLE Master_Orders;

CREATE TABLE Master_Orders (
   Cust_no varchar(6) NOT NULL,
   Order_No varchar(20) NOT NULL,
   Name varchar(30) NULL,
   Order_Date varchar(10) NOT NULL,
   Date_From varchar(10) NULL,
   Date_To varchar(10) NULL,
   Status varchar(15) NULL,
   Comments varchar(200) NULL,
   Next_Seq_Number integer NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Orders_Cust_no ON Master_Orders (Cust_no,Order_No,Order_Date);

DROP TABLE Master_Order_Items;

CREATE TABLE Master_Order_Items (
   Cust_no varchar(6) NOT NULL,
   Order_No varchar(20) NOT NULL,
   Name varchar(30) NULL,
   Order_Date varchar(10) NOT NULL,
   Seq_Number integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Recipe_No integer NOT NULL,
   Qty_Ordered numeric(10,2) NOT NULL,
   Qty_to_Allocate numeric(10,2) NULL,
   Status varchar(15) NULL,
   Next_Seq_No integer NULL,
   Programme_Date varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Order_Items_Cust_no ON Master_Order_Items (Cust_no,Order_No,Order_Date,Seq_Number,Family_Name,Family_Type,Product_Size,Package_Size,Recipe_No);

DROP TABLE Master_Order_Qty_Allocated;

CREATE TABLE Master_Order_Qty_Allocated (
   Cust_no varchar(6) NOT NULL,
   Order_No varchar(20) NOT NULL,
   Name varchar(30) NULL,
   Order_Date varchar(10) NOT NULL,
   Seq_Number integer NOT NULL,
   Inv_Seq integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Recipe_No integer NOT NULL,
   Qty_to_Allocate numeric(10,2) NULL,
   RN_Recipe_No integer NOT NULL,
   RN_Family_Name varchar(60) NOT NULL,
   RN_Family_Type varchar(20) NOT NULL,
   RN_Product_Size varchar(6) NOT NULL,
   RN_Package_Size numeric(6,0) NOT NULL,
   Prod_Run_No varchar(6) NOT NULL,
   Date_Allocated varchar(10) NULL,
   Time_Allocated varchar(8) NULL,
   Warehouse_Name varchar(20) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Order_Qty_Allocated_Cust_no ON Master_Order_Qty_Allocated (Cust_no,Order_No,Order_Date,Seq_Number,Inv_Seq,Family_Name,Family_Type,Product_Size,Package_Size,Recipe_No,Prod_Run_No);

CREATE INDEX Master_Order_Qty_Allocated_RN_Recipe_No ON Master_Order_Qty_Allocated (RN_Recipe_No);

CREATE INDEX Master_Order_Qty_Allocated_RN_Family_Name ON Master_Order_Qty_Allocated (RN_Family_Name);

CREATE INDEX Master_Order_Qty_Allocated_RN_Family_Type ON Master_Order_Qty_Allocated (RN_Family_Type);

CREATE INDEX Master_Order_Qty_Allocated_RN_Product_Size ON Master_Order_Qty_Allocated (RN_Product_Size);

CREATE INDEX Master_Order_Qty_Allocated_RN_Package_Size ON Master_Order_Qty_Allocated (RN_Package_Size);

CREATE INDEX Master_Order_Qty_Allocated_Warehouse_Name ON Master_Order_Qty_Allocated (Warehouse_Name);

DROP TABLE Master_Product;

CREATE TABLE Master_Product (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Recipe_No ON Master_Product (Recipe_No,Family_Name,Family_Type,Product_Size);

DROP TABLE Master_Product_Control;

CREATE TABLE Master_Product_Control (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Created_Date varchar(10) NOT NULL,
   Created_Time varchar(10) NOT NULL,
   Version_No integer NOT NULL,
   Package_Code varchar(15) NULL,
   Used_by_date varchar(10) NULL,
   Label_Colour varchar(15) NULL,
   Comment varchar(200) NULL,
   Remill integer NULL,
   Qty_In_Stock numeric(10,2) NULL,
   Loss_Factor numeric(10,2) NULL,
   Archive varchar(4) NULL,
   Prod_Process varchar(15) NULL,
   Run_Time numeric(10,2) NULL,
   Die_Change_Time numeric(10,2) NULL,
   Cost numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Control_Recipe_No ON Master_Product_Control (Recipe_No,Family_Name,Family_Type,Product_Size,Created_Date,Created_Time);

CREATE INDEX Master_Product_Control_Used_by_date ON Master_Product_Control (Used_by_date);

DROP TABLE Master_Product_Ingredient;

CREATE TABLE Master_Product_Ingredient (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Created_Date varchar(10) NOT NULL,
   Created_Time varchar(10) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Version_No integer NOT NULL,
   Qty_Per numeric(10,2) NOT NULL,
   Qty_Required numeric(10,3) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Ingredient_Recipe_No ON Master_Product_Ingredient (Recipe_No,Family_Name,Family_Type,Product_Size,Created_Date,Created_Time,Raw_Material_Name);

DROP TABLE Master_Product_Packing;

CREATE TABLE Master_Product_Packing (
   Prod_Run_No varchar(6) NOT NULL,
   Prod_Date varchar(10) NOT NULL,
   Pallet_No integer NOT NULL,
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Created_Date varchar(10) NOT NULL,
   Created_Time varchar(10) NOT NULL,
   First_Bag_No integer NOT NULL,
   Last_Bag_No integer NOT NULL,
   Bag_Pallet integer NOT NULL,
   Date_Packed varchar(10) NOT NULL,
   Staff_Name varchar(40) NOT NULL,
   Bag_Weight_Check numeric(10,2) NULL,
   Sink_test varchar(10) NULL,
   Sink_Percent integer NULL,
   Bulk_Density numeric(10,2) NULL,
   Dust varchar(10) NULL,
   Chipped varchar(10) NULL,
   Surface_Oil varchar(10) NULL,
   Pellet_Hardness varchar(10) NULL,
   Length_Min numeric(5,2) NULL,
   Length_Max numeric(5,2) NULL,
   Length_Shape varchar(10) NULL,
   Diameter_Min numeric(5,2) NULL,
   Diameter_Max numeric(5,2) NULL,
   Diameter_Shape varchar(10) NULL,
   NCR_Completed varchar(4) NULL,
   Quality_Status varchar(15) NOT NULL,
   Time_Packed varchar(8) NULL,
   Comment varchar(200) NULL,
   Warehouse_Name varchar(20) NOT NULL,
   Loc_No integer NOT NULL,
   Amb_Temp numeric(10,1) NULL,
   Bag_Temp numeric(10,1) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Packing_Prod_Run_No ON Master_Product_Packing (Prod_Run_No,Prod_Date,Pallet_No,Recipe_No,Family_Name,Family_Type,Product_Size,Package_Size,Created_Date,Created_Time);

CREATE INDEX Master_Product_Packing_Staff_Name ON Master_Product_Packing (Staff_Name);

CREATE INDEX Master_Product_Packing_Warehouse_Name ON Master_Product_Packing (Warehouse_Name);

CREATE INDEX Master_Product_Packing_Loc_No ON Master_Product_Packing (Loc_No);

DROP TABLE Master_Product_Production;

CREATE TABLE Master_Product_Production (
   Prod_Date varchar(10) NOT NULL,
   Prod_Run_No varchar(6) NOT NULL,
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Created_Date varchar(10) NOT NULL,
   Created_Time varchar(10) NOT NULL,
   Version_No integer NULL,
   Package_Code varchar(15) NULL,
   Label_Colour varchar(15) NULL,
   Week_No integer NOT NULL,
   Start_Time varchar(8) NULL,
   Qty_to_Produced numeric(10,2) NOT NULL,
   Run_Hours_Planned numeric(10,2) NULL,
   Batches_Req integer NOT NULL,
   Actual_Batches_Used integer NULL,
   Bags_Required integer NOT NULL,
   Actual_Bags_Used integer NULL,
   Qty_Batched numeric(10,2) NULL,
   Actual_Produced numeric(10,2) NULL,
   Waste_Planned numeric(10,2) NULL,
   Actual_Waste numeric(10,2) NULL,
   Reblend_Planned numeric(10,2) NULL,
   Actual_Reblend numeric(10,2) NULL,
   Next_Seq_Number integer NULL,
   Archive varchar(4) NULL,
   Last_Update_Date varchar(10) NULL,
   Last_Update_Time varchar(8) NULL,
   Comment varchar(200) NULL,
   Person_Responsible varchar(40) NOT NULL,
   Moisture numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Production_Prod_Date ON Master_Product_Production (Prod_Date,Prod_Run_No,Recipe_No,Family_Name,Family_Type,Product_Size,Package_Size,Created_Date,Created_Time);

CREATE INDEX Master_Product_Production_Person_Responsible ON Master_Product_Production (Person_Responsible);

DROP TABLE Master_Product_Programme;

CREATE TABLE Master_Product_Programme (
   Cust_no varchar(6) NOT NULL,
   Order_No varchar(20) NOT NULL,
   Name varchar(30) NULL,
   Order_Date varchar(10) NOT NULL,
   Seq_Number integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Recipe_No integer NOT NULL,
   Qty_to_produce numeric(10,2) NULL,
   Batches_Req integer NULL,
   Bags_Required integer NULL,
   Pallets_Required integer NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Programme_Cust_no ON Master_Product_Programme (Cust_no,Order_No,Order_Date,Seq_Number,Family_Name,Family_Type,Product_Size,Package_Size,Recipe_No);

DROP TABLE Master_Product_Return;

CREATE TABLE Master_Product_Return (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Prod_Run_No varchar(6) NOT NULL,
   Transfer_Date varchar(10) NOT NULL,
   Next_Seq_Num integer NOT NULL,
   Qty_Transfered numeric(10,2) NOT NULL,
   Transfered_to varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Return_Recipe_No ON Master_Product_Return (Recipe_No,Family_Name,Family_Type,Product_Size,Package_Size,Prod_Run_No,Transfer_Date,Next_Seq_Num);

DROP TABLE Master_Product_Runs;

CREATE TABLE Master_Product_Runs (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Prod_Run_No varchar(6) NOT NULL,
   Prod_Date varchar(10) NOT NULL,
   Time_Produced varchar(8) NULL,
   Qty_On_Hold numeric(10,2) NULL,
   Qty_Produced numeric(10,2) NOT NULL,
   Next_Seq_No integer NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Runs_Recipe_No ON Master_Product_Runs (Recipe_No,Family_Name,Family_Type,Product_Size,Package_Size,Prod_Run_No);

CREATE INDEX Master_Product_Runs_Prod_Date ON Master_Product_Runs (Prod_Date);

DROP TABLE Master_Product_Spec;

CREATE TABLE Master_Product_Spec (
   Spec_Date varchar(10) NOT NULL,
   Spec_Time varchar(8) NOT NULL,
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Constituent varchar(20) NOT NULL,
   Version_No integer NULL,
   Min_Value numeric(10,2) NOT NULL,
   Min_Action varchar(200) NULL,
   Max_Value numeric(10,2) NOT NULL,
   Max_Action varchar(200) NULL,
   Target_Value numeric(10,2) NULL,
   Tolerence numeric(6,2) NULL,
   Units varchar(10) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Spec_Spec_Date ON Master_Product_Spec (Spec_Date,Spec_Time,Recipe_No,Family_Name,Family_Type,Product_Size,Constituent);

DROP TABLE Master_Product_Transfer;

CREATE TABLE Master_Product_Transfer (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NOT NULL,
   Prod_Run_No varchar(6) NOT NULL,
   Transfer_Date varchar(10) NOT NULL,
   Next_Seq_Num integer NOT NULL,
   Qty_Transfered numeric(10,2) NOT NULL,
   Warehouse_Name varchar(20) NOT NULL,
   Loc_No integer NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Master_Product_Transfer_Recipe_No ON Master_Product_Transfer (Recipe_No,Family_Name,Family_Type,Product_Size,Package_Size,Prod_Run_No,Transfer_Date,Next_Seq_Num);

CREATE INDEX Master_Product_Transfer_Warehouse_Name ON Master_Product_Transfer (Warehouse_Name);

CREATE INDEX Master_Product_Transfer_Loc_No ON Master_Product_Transfer (Loc_No);

DROP TABLE MP_Raw_Material_History;

CREATE TABLE MP_Raw_Material_History (
   Recipe_No integer NOT NULL,
   Family_Name varchar(60) NOT NULL,
   Family_Type varchar(20) NOT NULL,
   Product_Size varchar(6) NOT NULL,
   Package_Size numeric(6,0) NULL,
   Created_Date varchar(10) NOT NULL,
   Created_Time varchar(10) NOT NULL,
   Version_No integer NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Qty_Used numeric(10,2) NOT NULL,
   Used_Date varchar(10) NOT NULL,
   Used_Time varchar(8) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX MP_Raw_Material_History_Recipe_No ON MP_Raw_Material_History (Recipe_No,Family_Name,Family_Type,Product_Size,Created_Date,Created_Time,Raw_Material_Name,Used_Date,Used_Time);

DROP TABLE NIR_Result;

CREATE TABLE NIR_Result (
   Record_Id integer NOT NULL,
   Sample_Id integer NOT NULL,
   Sample_Date varchar(10) NOT NULL,
   Sample_Id_No varchar(20) NULL,
   Supplier_Name varchar(60) NOT NULL,
   Supplier_Code varchar(10) NOT NULL,
   GRN_No varchar(15) NULL,
   Raw_Material_Name varchar(30) NULL,
   Constituent varchar(20) NULL,
   R_Result numeric(10,2) NULL,
   Prod_Run_No varchar(6) NULL,
   Recipe_No integer NULL,
   Family_Name varchar(60) NULL,
   Product_Size varchar(6) NULL,
   Family_Type varchar(20) NULL,
   MP_Constituent varchar(20) NULL,
   Pallet_No varchar(15) NULL,
   Result numeric(10,2) NULL,
   In_Tolerence varchar(4) NULL,
   Accepted varchar(4) NULL,
   Reason varchar(60) NULL,
   Person_Responsible varchar(40) NULL,
   Storage_Location varchar(30) NULL,
   Spec_Date varchar(10) NULL,
   Spec_Time varchar(8) NULL,
   Sink_test varchar(10) NULL,
   Sink_Percent integer NULL,
   Bulk_Density numeric(10,2) NULL,
   Fines numeric(10,2) NULL,
   Diam_Check numeric(10,2) NULL,
   Length_Min numeric(5,2) NULL,
   Length_Max numeric(5,2) NULL,
   Comment varchar(200) NULL,
   Water numeric(10,2) NULL,
   Location_Name varchar(30) NULL,
   R_Spec_Date varchar(10) NULL,
   R_Spec_Time varchar(8) NULL
);

CREATE UNIQUE CLUSTERED INDEX NIR_Result_Record_Id ON NIR_Result (Record_Id,Sample_Id,Sample_Date);

CREATE INDEX NIR_Result_Supplier_Name ON NIR_Result (Supplier_Name);

CREATE INDEX NIR_Result_Raw_Material_Name ON NIR_Result (Raw_Material_Name);

CREATE INDEX NIR_Result_Recipe_No ON NIR_Result (Recipe_No);

CREATE INDEX NIR_Result_Family_Name ON NIR_Result (Family_Name);

CREATE INDEX NIR_Result_Person_Responsible ON NIR_Result (Person_Responsible);

DROP TABLE Oil_Batch_Recipe;

CREATE TABLE Oil_Batch_Recipe (
   id integer NOT NULL,
   recipe varchar(50) NOT NULL,
   batchmass varchar(50) NULL,
   fishoilp varchar(50) NULL,
   vegoilp varchar(50) NULL,
   sv1 varchar(50) NULL,
   sv2 varchar(50) NULL,
   sv3 varchar(50) NULL,
   sv4 varchar(50) NULL,
   sv5 varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX Oil_Batch_Recipe_id ON Oil_Batch_Recipe (id,recipe);

DROP TABLE Package_Size;

CREATE TABLE Package_Size (
   Package_Size numeric(6,0) NOT NULL,
   Package_Type varchar(10) NULL,
   Description varchar(60) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Package_Size_Package_Size ON Package_Size (Package_Size);

CREATE INDEX Package_Size_Package_Type ON Package_Size (Package_Type);

DROP TABLE Pallets_Adjustment;

CREATE TABLE Pallets_Adjustment (
   Cust_no varchar(6) NOT NULL,
   Name varchar(30) NULL,
   Adjust_Date varchar(10) NOT NULL,
   Adjust_Qty integer NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Pallets_Adjustment_Cust_no ON Pallets_Adjustment (Cust_no,Adjust_Date);

DROP TABLE Part;

CREATE TABLE Part (
   Part_No varchar(30) NOT NULL,
   Name varchar(60) NOT NULL,
   Cost numeric(12,2) NULL,
   Qis integer NULL,
   ReOrder integer NULL,
   Min_order integer NULL,
   Max_Order integer NULL,
   Comments varchar(255) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Part_Part_No ON Part (Part_No,Name);

DROP TABLE Parts_Orders;

CREATE TABLE Parts_Orders (
   Order_No varchar(20) NOT NULL,
   Person_Name varchar(60) NULL,
   Order_Date varchar(10) NOT NULL,
   Supplier_Name varchar(60) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Parts_Orders_Order_No ON Parts_Orders (Order_No);

CREATE INDEX Parts_Orders_Person_Name ON Parts_Orders (Person_Name);

CREATE INDEX Parts_Orders_Supplier_Name ON Parts_Orders (Supplier_Name);

DROP TABLE Parts_Order_Items;

CREATE TABLE Parts_Order_Items (
   Order_No varchar(20) NOT NULL,
   Part_No varchar(30) NOT NULL,
   Part_Name varchar(60) NULL,
   Qty_Ordered integer NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Parts_Order_Items_Order_No ON Parts_Order_Items (Order_No,Part_No);

CREATE INDEX Parts_Order_Items_Part_Name ON Parts_Order_Items (Part_Name);

DROP TABLE Parts_Used;

CREATE TABLE Parts_Used (
   Schedule_No integer NOT NULL,
   Schedule_Date varchar(10) NOT NULL,
   Part_No varchar(30) NOT NULL,
   Name varchar(60) NOT NULL,
   Qty_Used integer NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Parts_Used_Schedule_No ON Parts_Used (Schedule_No,Schedule_Date,Part_No);

CREATE INDEX Parts_Used_Name ON Parts_Used (Name);

DROP TABLE Passwords;

CREATE TABLE Passwords (
   Password_Id varchar(20) NOT NULL,
   Value varchar(40) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Passwords_Password_Id ON Passwords (Password_Id);

DROP TABLE Person;

CREATE TABLE Person (
   Name varchar(60) NOT NULL,
   Contact varchar(20) NULL,
   Mobile varchar(20) NULL,
   Comments varchar(255) NULL,
   Email varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Person_Name ON Person (Name);

DROP TABLE Product_Size;

CREATE TABLE Product_Size (
   Product_Size varchar(6) NOT NULL,
   Description varchar(60) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Product_Size_Product_Size ON Product_Size (Product_Size);

DROP TABLE Rack_Location;

CREATE TABLE Rack_Location (
   Warehouse_Name varchar(20) NOT NULL,
   Loc_No integer NOT NULL,
   Location varchar(40) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Rack_Location_Warehouse_Name ON Rack_Location (Warehouse_Name,Loc_No);

CREATE INDEX Rack_Location_Location ON Rack_Location (Location);

DROP TABLE Raw;

CREATE TABLE Raw (
   Raw_Material_Name varchar(30) NOT NULL,
   Raw_Material_No integer NOT NULL,
   Total_Qty numeric(10,2) NULL,
   Qty_Allocated numeric(10,2) NULL,
   Reorder_Level numeric(10,2) NULL,
   Active_Level numeric(10,2) NULL,
   Sow_Name varchar(50) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Raw_Material_Name ON Raw (Raw_Material_Name);

CREATE INDEX Raw_Raw_Material_No ON Raw (Raw_Material_No);

DROP TABLE Raw_Material_Invoice;

CREATE TABLE Raw_Material_Invoice (
   Order_No varchar(20) NOT NULL,
   Cust_no varchar(6) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Location_Name varchar(30) NOT NULL,
   Carrier_Name varchar(20) NOT NULL,
   Qty_Delivered numeric(10,2) NOT NULL,
   Qty_Returned numeric(10,2) NULL,
   Delivered_Date varchar(10) NOT NULL,
   Qty_Ordered numeric(10,2) NULL,
   Cost_Price numeric(10,2) NULL,
   Price_Type varchar(15) NULL,
   Pallets_In numeric(6,0) NOT NULL,
   Pallets_Out numeric(6,0) NOT NULL,
   Status varchar(10) NULL,
   Invoice_No varchar(15) NULL,
   Credit varchar(4) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Material_Invoice_Order_No ON Raw_Material_Invoice (Order_No,Cust_no,Order_Date,Raw_Material_Name);

CREATE INDEX Raw_Material_Invoice_Carrier_Name ON Raw_Material_Invoice (Carrier_Name);

CREATE INDEX Raw_Material_Invoice_Delivered_Date ON Raw_Material_Invoice (Delivered_Date);

CREATE INDEX Raw_Material_Invoice_Status ON Raw_Material_Invoice (Status);

CREATE INDEX Raw_Material_Invoice_Invoice_No ON Raw_Material_Invoice (Invoice_No);

DROP TABLE Raw_Material_Location;

CREATE TABLE Raw_Material_Location (
   Raw_Material_Name varchar(30) NOT NULL,
   Location_Name varchar(30) NOT NULL,
   Qty_On_Hand numeric(10,2) NULL,
   Stock_Take numeric(10,2) NULL,
   Last_Stock_Take numeric(10,2) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Material_Location_Raw_Material_Name ON Raw_Material_Location (Raw_Material_Name,Location_Name);

DROP TABLE Raw_Material_Order;

CREATE TABLE Raw_Material_Order (
   Order_No varchar(20) NOT NULL,
   Supplier_Name varchar(60) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Qty_Ordered numeric(10,2) NOT NULL,
   Expected_Date varchar(10) NULL,
   Total_Delivered numeric(10,2) NULL,
   Total_Undelivered numeric(10,2) NULL,
   Status varchar(15) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Material_Order_Order_No ON Raw_Material_Order (Order_No);

CREATE INDEX Raw_Material_Order_Supplier_Name ON Raw_Material_Order (Supplier_Name);

CREATE INDEX Raw_Material_Order_Order_Date ON Raw_Material_Order (Order_Date);

CREATE INDEX Raw_Material_Order_Raw_Material_Name ON Raw_Material_Order (Raw_Material_Name);

CREATE INDEX Raw_Material_Order_Expected_Date ON Raw_Material_Order (Expected_Date);

DROP TABLE Raw_Material_Received;

CREATE TABLE Raw_Material_Received (
   Raw_Material_Name varchar(30) NOT NULL,
   Location_Name varchar(30) NOT NULL,
   Received_Date varchar(10) NOT NULL,
   Received_Time varchar(10) NOT NULL,
   Qty_Received numeric(10,2) NOT NULL,
   Receive_Number varchar(20) NOT NULL,
   Reference_Number varchar(20) NOT NULL,
   Supplier varchar(60) NOT NULL,
   Container_No varchar(30) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Material_Received_Raw_Material_Name ON Raw_Material_Received (Raw_Material_Name,Location_Name,Received_Date,Received_Time);

CREATE INDEX Raw_Material_Received_Reference_Number ON Raw_Material_Received (Reference_Number);

DROP TABLE Raw_Material_Return;

CREATE TABLE Raw_Material_Return (
   Order_No varchar(20) NOT NULL,
   Cust_no varchar(6) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Return_Date varchar(10) NOT NULL,
   Qty_Returned numeric(10,2) NOT NULL,
   Reason varchar(150) NOT NULL,
   Return_Status varchar(15) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Material_Return_Order_No ON Raw_Material_Return (Order_No,Cust_no,Order_Date,Raw_Material_Name,Return_Date);

DROP TABLE Raw_Material_Spec;

CREATE TABLE Raw_Material_Spec (
   Spec_Date varchar(10) NOT NULL,
   Spec_Time varchar(8) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Person_Responsible varchar(40) NOT NULL,
   Comment varchar(255) NULL,
   Archive varchar(4) NULL,
   File_Location varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Material_Spec_Spec_Date ON Raw_Material_Spec (Spec_Date,Spec_Time,Raw_Material_Name);

CREATE INDEX Raw_Material_Spec_Person_Responsible ON Raw_Material_Spec (Person_Responsible);

DROP TABLE Raw_Mat_In_Transit;

CREATE TABLE Raw_Mat_In_Transit (
   Order_No varchar(20) NOT NULL,
   Supplier_Name varchar(60) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Qty_Ordered numeric(10,2) NOT NULL,
   Expected_Date varchar(10) NULL,
   Transit_Date varchar(10) NOT NULL,
   Container_No varchar(30) NOT NULL,
   Qty_In_Transit numeric(10,2) NOT NULL,
   Loc_Name varchar(30) NOT NULL,
   Status varchar(12) NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Mat_In_Transit_Order_No ON Raw_Mat_In_Transit (Order_No,Transit_Date,Container_No);

CREATE INDEX Raw_Mat_In_Transit_Supplier_Name ON Raw_Mat_In_Transit (Supplier_Name);

CREATE INDEX Raw_Mat_In_Transit_Order_Date ON Raw_Mat_In_Transit (Order_Date);

CREATE INDEX Raw_Mat_In_Transit_Raw_Material_Name ON Raw_Mat_In_Transit (Raw_Material_Name);

CREATE INDEX Raw_Mat_In_Transit_Expected_Date ON Raw_Mat_In_Transit (Expected_Date);

CREATE INDEX Raw_Mat_In_Transit_Loc_Name ON Raw_Mat_In_Transit (Loc_Name);

DROP TABLE Raw_Mat_Spec_Item;

CREATE TABLE Raw_Mat_Spec_Item (
   Spec_Date varchar(10) NOT NULL,
   Spec_Time varchar(8) NOT NULL,
   Raw_Material_Name varchar(30) NOT NULL,
   Constituent varchar(20) NOT NULL,
   Min_Value numeric(10,2) NOT NULL,
   Min_Action varchar(200) NULL,
   Max_Value numeric(10,2) NOT NULL,
   Max_Action varchar(200) NULL,
   Target_Value numeric(10,2) NULL,
   Tolerence numeric(6,2) NULL,
   Units varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Raw_Mat_Spec_Item_Spec_Date ON Raw_Mat_Spec_Item (Spec_Date,Spec_Time,Raw_Material_Name,Constituent);

DROP TABLE Recipe_No;

CREATE TABLE Recipe_No (
   Recipe_No integer NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Recipe_No_Recipe_No ON Recipe_No (Recipe_No);

DROP TABLE Remill_Waste;

CREATE TABLE Remill_Waste (
   Shift_Date varchar(10) NOT NULL,
   Shift_Time varchar(15) NOT NULL,
   Time_Actioned varchar(8) NOT NULL,
   Fines_Overs numeric(10,2) NULL,
   Chute_No integer NULL,
   Bin_5 numeric(10,2) NULL,
   Wet_Waste numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Remill_Waste_Shift_Date ON Remill_Waste (Shift_Date,Shift_Time,Time_Actioned);

DROP TABLE Report_Options;

CREATE TABLE Report_Options (
   Record_Id integer NOT NULL,
   Add_Title varchar(4) NOT NULL,
   Company_Details varchar(4) NOT NULL,
   Zeros varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Report_Options_Record_Id ON Report_Options (Record_Id);

DROP TABLE Responsible_to;

CREATE TABLE Responsible_to (
   Name varchar(60) NOT NULL,
   Section_No varchar(20) NULL,
   Section_Name varchar(60) NULL,
   Item_Id varchar(20) NULL,
   Item_Name varchar(60) NULL,
   Comments varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Responsible_to_Name ON Responsible_to (Name);

CREATE INDEX Responsible_to_Section_No ON Responsible_to (Section_No);

CREATE INDEX Responsible_to_Section_Name ON Responsible_to (Section_Name);

CREATE INDEX Responsible_to_Item_Id ON Responsible_to (Item_Id);

CREATE INDEX Responsible_to_Item_Name ON Responsible_to (Item_Name);

DROP TABLE runtable;

CREATE TABLE runtable (
   run varchar(50) NOT NULL,
   formula varchar(50) NULL,
   batch_total varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX runtable_run ON runtable (run);

DROP TABLE Scale1_Batch_Data;

CREATE TABLE Scale1_Batch_Data (
   run varchar(50) NOT NULL,
   time1 varchar(20) NULL,
   date1 varchar(20) NULL,
   scale1 varchar(10) NULL,
   B1_Name varchar(30) NULL,
   B2_Name varchar(30) NULL,
   B1_Mass varchar(10) NULL,
   B2_Mass varchar(10) NULL,
   B3_Name varchar(30) NULL,
   B4_Name varchar(30) NULL,
   B3_Mass varchar(10) NULL,
   B4_Mass varchar(10) NULL,
   B5_Name varchar(30) NULL,
   B6_Name varchar(30) NULL,
   B5_Mass varchar(10) NULL,
   B6_Mass varchar(10) NULL,
   B7_Name varchar(30) NULL,
   B8_Name varchar(30) NULL,
   B7_Mass varchar(10) NULL,
   B8_Mass varchar(10) NULL,
   B9_Name varchar(30) NULL,
   B10_Name varchar(30) NULL,
   B9_Mass varchar(10) NULL,
   B10_Mass varchar(10) NULL,
   B11_Name varchar(30) NULL,
   B12_Name varchar(30) NULL,
   B11_Mass varchar(10) NULL,
   B12_Mass varchar(10) NULL,
   B13_Name varchar(30) NULL,
   B14_Name varchar(30) NULL,
   B13_Mass varchar(10) NULL,
   B14_Mass varchar(10) NULL,
   B15_Name varchar(30) NULL,
   B16_Name varchar(30) NULL,
   B15_Mass varchar(10) NULL,
   B16_Mass varchar(10) NULL,
   B17_Name varchar(30) NULL,
   B18_Name varchar(30) NULL,
   B17_Mass varchar(10) NULL,
   B18_Mass varchar(10) NULL,
   B19_Name varchar(30) NULL,
   B20_Name varchar(30) NULL,
   B19_Mass varchar(10) NULL,
   B20_Mass varchar(10) NULL,
   B21_Name varchar(30) NULL,
   B22_Name varchar(30) NULL,
   B21_Mass varchar(10) NULL,
   B22_Mass varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Scale1_Batch_Data_run ON Scale1_Batch_Data (run);

DROP TABLE Scale2_Batch_Data;

CREATE TABLE Scale2_Batch_Data (
   run varchar(50) NOT NULL,
   time1 varchar(20) NULL,
   date1 varchar(20) NULL,
   scale1 varchar(10) NULL,
   B23_Name varchar(30) NULL,
   B24_Name varchar(30) NULL,
   B23_Mass varchar(10) NULL,
   B24_Mass varchar(10) NULL,
   B25_Name varchar(30) NULL,
   B25_Mass varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Scale2_Batch_Data_run ON Scale2_Batch_Data (run);

DROP TABLE Scale3_Batch_Data;

CREATE TABLE Scale3_Batch_Data (
   run varchar(50) NOT NULL,
   time1 varchar(20) NULL,
   date1 varchar(20) NULL,
   scale1 varchar(10) NULL,
   B26_Name varchar(30) NULL,
   B27_Name varchar(30) NULL,
   B26_Mass varchar(10) NULL,
   B27_Mass varchar(10) NULL,
   B28_Name varchar(30) NULL,
   B28_Mass varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Scale3_Batch_Data_run ON Scale3_Batch_Data (run);

DROP TABLE Schedule;

CREATE TABLE Schedule (
   Schedule_No integer NOT NULL,
   Schedule_Date varchar(10) NOT NULL,
   Details varchar(200) NULL,
   Completed_by varchar(60) NULL
);

CREATE UNIQUE CLUSTERED INDEX Schedule_Schedule_No ON Schedule (Schedule_No,Schedule_Date);

CREATE INDEX Schedule_Completed_by ON Schedule (Completed_by);

DROP TABLE Sections;

CREATE TABLE Sections (
   Section_No varchar(20) NOT NULL,
   Name varchar(60) NOT NULL,
   Comments varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Sections_Section_No ON Sections (Section_No,Name);

DROP TABLE Section_Item;

CREATE TABLE Section_Item (
   Section_No varchar(20) NOT NULL,
   Section_Name varchar(60) NOT NULL,
   Item_Id varchar(20) NOT NULL,
   Name varchar(60) NOT NULL,
   Maker_Name varchar(60) NULL,
   Comments varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Section_Item_Section_No ON Section_Item (Section_No,Section_Name,Item_Id,Name);

CREATE INDEX Section_Item_Maker_Name ON Section_Item (Maker_Name);

DROP TABLE Section_Sub_Item;

CREATE TABLE Section_Sub_Item (
   Section_No varchar(20) NOT NULL,
   Section_Name varchar(60) NOT NULL,
   Item_Id varchar(20) NOT NULL,
   Item_Name varchar(60) NOT NULL,
   Part_No varchar(20) NOT NULL,
   Part_Name varchar(60) NOT NULL,
   Comments varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Section_Sub_Item_Section_No ON Section_Sub_Item (Section_No,Section_Name,Item_Id,Item_Name,Part_No,Part_Name);

DROP TABLE SeqNum;

CREATE TABLE SeqNum (
   tablename varchar(30) NOT NULL,
   nextid integer NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX SeqNum_tablename ON SeqNum (tablename);

DROP TABLE Shift;

CREATE TABLE Shift (
   Shift_Date varchar(10) NOT NULL,
   Shift_Time varchar(15) NOT NULL,
   Name1 varchar(40) NOT NULL,
   Name2 varchar(40) NOT NULL,
   Name3 varchar(40) NULL,
   Total_Mouldy integer NULL,
   Total_Ripped integer NULL,
   Total_Ties_Cut integer NULL,
   Comments varchar(100) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Shift_Shift_Date ON Shift (Shift_Date,Shift_Time);

CREATE INDEX Shift_Name1 ON Shift (Name1);

CREATE INDEX Shift_Name2 ON Shift (Name2);

CREATE INDEX Shift_Name3 ON Shift (Name3);

DROP TABLE Shift_DownTime;

CREATE TABLE Shift_DownTime (
   Shift_Date varchar(10) NOT NULL,
   Shift_Time varchar(15) NOT NULL,
   Reason varchar(60) NULL,
   Stop_Time varchar(8) NULL,
   StartH varchar(8) NULL,
   DownH varchar(20) NULL,
   CommentH varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX Shift_DownTime_Shift_Date ON Shift_DownTime (Shift_Date,Shift_Time);

DROP TABLE Staff;

CREATE TABLE Staff (
   Name varchar(40) NOT NULL,
   Address varchar(50) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Staff_Name ON Staff (Name);

DROP TABLE Supplier;

CREATE TABLE Supplier (
   Supplier_Name varchar(60) NOT NULL,
   Supplier_Code varchar(10) NOT NULL,
   Address varchar(150) NULL,
   Suburb varchar(30) NULL,
   State varchar(3) NULL,
   Postcode integer NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Comments varchar(255) NULL,
   Mobile varchar(15) NULL
);

CREATE UNIQUE CLUSTERED INDEX Supplier_Supplier_Name ON Supplier (Supplier_Name);

DROP TABLE Supplier_Part;

CREATE TABLE Supplier_Part (
   Supplier_Name varchar(60) NOT NULL,
   Part_No varchar(30) NOT NULL,
   Name varchar(60) NOT NULL,
   Supplier_Part_No varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Supplier_Part_Supplier_Name ON Supplier_Part (Supplier_Name,Part_No,Name,Supplier_Part_No);

DROP TABLE Title_List;

CREATE TABLE Title_List (
   Title_Name varchar(100) NOT NULL,
   Description varchar(250) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Title_List_Title_Name ON Title_List (Title_Name);

DROP TABLE Units;

CREATE TABLE Units (
   Units varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Units_Units ON Units (Units);

DROP TABLE URIGHTS;

CREATE TABLE URIGHTS (
   USER_ID varchar(30) NOT NULL,
   TABLE_NAME varchar(50) NOT NULL,
   USTORE varchar(3) NOT NULL,
   UDELETE varchar(3) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX URIGHTS_USER_ID ON URIGHTS (USER_ID,TABLE_NAME);

DROP TABLE USERIDS;

CREATE TABLE USERIDS (
   USER_ID varchar(30) NOT NULL,
   NPASSWORD varchar(30) NOT NULL,
   Staff_Name varchar(40) NOT NULL,
   Start_Up_File varchar(100) NULL,
   User_Status varchar(10) NULL,
   INI_File varchar(128) NULL,
   On_Exit_Run varchar(128) NULL
);

CREATE UNIQUE CLUSTERED INDEX USERIDS_USER_ID ON USERIDS (USER_ID);

CREATE INDEX USERIDS_Staff_Name ON USERIDS (Staff_Name);

DROP TABLE User_Preferences;

CREATE TABLE User_Preferences (
   USER_ID varchar(30) NOT NULL,
   Pref_Name varchar(60) NOT NULL,
   Pref_Setting varchar(128) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX User_Preferences_USER_ID ON User_Preferences (USER_ID,Pref_Name);

DROP TABLE UTABLES;

CREATE TABLE UTABLES (
   TABLE_NAME varchar(50) NOT NULL,
   Screen_Name varchar(60) NULL
);

CREATE UNIQUE CLUSTERED INDEX UTABLES_TABLE_NAME ON UTABLES (TABLE_NAME);

DROP TABLE Warehouse;

CREATE TABLE Warehouse (
   Name varchar(20) NOT NULL,
   Address varchar(50) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Is_Default varchar(4) NULL,
   Contact varchar(40) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Warehouse_Name ON Warehouse (Name);

DROP TABLE Reason_for_Fail;

CREATE TABLE Reason_for_Fail (
   Reason varchar(60) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Reason_for_Fail_Reason ON Reason_for_Fail (Reason);

